#
# spec file for package python-jupytext
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define mainver 1.3.4
%define labver  1.1.1
Name:           python-jupytext
Version:        %{mainver}
Release:        bp153.1.16
Summary:        Tool to convert Jupyter notebooks to other formats
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/mwouts/jupytext
Source:         https://files.pythonhosted.org/packages/source/j/jupytext/jupytext-%{mainver}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  jupyter-jupyterlab-filesystem
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  python-rpm-macros
Requires:       jupyter-jupytext = %{mainver}
Requires:       python-PyYAML
Requires:       python-nbformat >= 4.0.0
Requires:       python-notebook
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nbformat >= 4.0.0}
BuildRequires:  %{python_module testfixtures}
# /SECTION
%python_subpackages

%description
Jupytext can save Jupyter notebooks as:

   * Markdown and R Markdown documents,
   * Julia, Python, R, Bash, Scheme, Clojure, Matlab, Octave, C++ and q/kdb+ scripts.
interactive computing.

This package provides the python interface.

%package     -n jupyter-jupytext
Summary:        Tool to convert Jupyter notebooks to other formats
Group:          Development/Languages/Python
Requires:       jupyter-nbformat >= 4.0.0
Requires:       jupyter-notebook
Requires:       python3-jupytext = %{mainver}

%description -n jupyter-jupytext
Jupytext can save Jupyter notebooks as:

   * Markdown and R Markdown documents,
   * Julia, Python, R, Bash, Scheme, Clojure, Matlab, Octave, C++ and q/kdb+ scripts.
interactive computing.

This package provides the exectuables and jupyter components.

%package     -n jupyter-jupytext-jupyterlab
Version:        %{labver}
Summary:        Tool to convert Jupyter notebooks to other formats
Group:          Development/Languages/Python
Requires:       jupyter-jupyterlab
Requires:       python3-jupytext = %{mainver}

%description -n jupyter-jupytext-jupyterlab
Jupytext can save Jupyter notebooks as:

   * Markdown and R Markdown documents,
   * Julia, Python, R, Bash, Scheme, Clojure, Matlab, Octave, C++ and q/kdb+ scripts.

This package provides the JupyterLab extension.

%prep
%setup -q -n jupytext-%{mainver}
sed -i 's/\r$//' README.md

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%jupyter_move_config

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/jupytext-%{mainver}-py*.egg-info
%{python_sitelib}/jupytext/

%files -n jupyter-jupytext
%license LICENSE
%{_bindir}/jupytext
%config %{_jupyter_server_confdir}/jupytext.json
%config %{_jupyter_servextension_confdir}/jupytext.json
%config %{_jupyter_nb_notebook_confdir}/jupytext.json
%{_jupyter_nbextension_dir}/jupytext/

%files -n jupyter-jupytext-jupyterlab
%license LICENSE
%{_jupyter_labextensions_dir}/jupyterlab-jupytext-%{labver}.tgz

%changelog
* Mon Feb 24 2020 Todd R <toddrme2178@gmail.com>
- Update to version 1.3.4
  + Added
  * C# and F# Jupyter notebooks are now supported
  + Fixed
  * `jupytext --to script *.ipynb` now computes the script extension for each notebook
  * Fix shebang handling for languages with non-# comments, by Jonas Bushart
  * Indented bash commands are now commented out
  * The main formats are documented in `jupytext --help`
- Update to version 1.3.3
  + Added
  * Jupytext has a logo! Many thanks to Kyle Kelley for contributing the actual logo, and to Chris Holdgraf for suggesting this.
  * Nested metadata filtering is now supported! You can use this to rid of `jupytext_version` if you wish.
  + Fixed
  * Code cells in the Markdown format can contain triple backticks inside multiline strings.
  * Changes in the YAML header when running `jupytext --test` on text files are ignored.
- Update to version 1.3.2
  + Fixed
  * The `--pre-commit` mode now ignores non-notebook files in the index.
  * `nbformat_minor` is taken from the notebook with outputs When inputs and outputs are merged.
- Update to version 1.3.1
  + Added
  * New `nomarker` format in the Jupyter Notebook and JupyterLab extensions
  + Changed
  * The `normarker` format replaces the one previously named `bare`.
  + Fixed
  * Multiline strings are now accepted in the YAML header. Fix contributed by ZHUO Qiang.
  * Fixed the instructions on how to use multiline comments for all Markdown cells in the py:percent format, by ZHUO Qiang.
  * Added `cd` to the list of magic commands.
  * Do not read paired files when `--set-formats` is being used.
- Update to version 1.3.0
  + Added
  * Pairing a notebook to both `.md` and `.py` is now supported. Input cells are loaded from the most recent text representation
  * Both the Jupyter Notebook and the Jupyter Lab extension for Jupytext were updated
  * Raw cells are now encoded using HTML comments (`<!-- #raw -->` and `<!-- #endraw -->`) in Markdown files
  * Markdown cells can be delimited with any of `<!-- #region -->`,  `<!-- #markdown -->` or `<!-- #md -->`
  * Code blocks from Markdown files, when they don't have an explicit language, appear in Markdown cells in Jupyter
  * Code blocks with an explicit language and a `.noeval` attribute are inactive in Jupyter
  * Markdown and raw cells can be quoted with triple quotes in the `py:percent` format. And Markdown cells can start with just `# %%%% [md]`
  * The light format uses `# + [markdown]` rather than the previous `cell_type` metadata to identify markdown cells with metadata
  * Explicit Markdown cells in the light format `# + [markdown]` can use triple quotes
  * IPython magic help commands like `float?` are classified as magics, and thus commented in Python scripts
  * Cell metadata can be encoded as either `key=value` (the new default) or in JSON. An automatic option `cell_metadata_json` should help minimize the impact on existing files
  * R Markdown hidden inputs, outputs, or cells are now mapped to the corresponding Jupyter Book tags by default
  * The notebook metadata filter is automatically updated when extra keys are added to the YAML header
  * The Jupyter Notebook extension for Jupytext is compatible with Jupyter Notebook 6.0
  * `jupytext notebook.py --to ipynb` updates the timestamp of `notebook.py` so that the paired notebook still works in Jupyter
  * `jupytext --check pytest notebook.ipynb` can be used to run test functions in a notebook
  * `jupytext --check` and `jupytext --pipe` can run commands that only operate on files: when `{}` is found in the text of the command, `jupytext` saves the text representation of the notebook in a temp file, and replaces `{}` with the name of that file before executing the command.
  * Documented how to sync notebooks in a pre-commit hook
  * Added support for Rust/Evxcr, by Jonas Bushart
  * Added support for [Robot Framework](https://robots-from-jupyter.github.io/), by Asko Soukka
  * Added support for PowerShell
  + Changed
  * Use `CHANGELOG.md` rather than `HISTORY.rst`
  + Fixed
  * Commands like `cat = x` are not magic commands, so they are not commented any more
  * Fixed an inconsistent round trip (code cell with `"cat"` being converted to a markdown cell) in the `py:light` format
  * `jupytext --test textfile.ext` now really compares the text file to its round trip (rather than the corresponding notebook)
  * Markdown cells that contain code are now preserved in a round trip through the Markdown and R Markdown formats
  * Code cells with a `%%%%python3` cell magic are now preserved in a round trip through the Markdown format
  * `jupytext --execute` runs the notebook in its folder
  * Strings in the metadata of code cells are quoted in the Rmd representation. And we escape R code in chunk options with `#R_CODE#`
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Drop python2 support due to python-notebook dropping python2 support
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.2.4
  + Improvements
  * The documentation includes a mention on how to set metadata filters at the command line
  * Jupytext will not catch any error when the flag ``--warn-only`` is not set
  + BugFixes
  * Now the flag ``--warn-only`` catches every possible error
  * ``.md`` and ``.markdown`` files are treated identically
  * Fixed ``--set-kernel`` when using pipes
  * Fixed utf-8 encoding on stdout on Python 2
- Update to 1.2.3
  + BugFixes
  * Dependency on ``setuptools`` in ``pandoc.py`` made optional to fix the build of the conda package
- Update to 1.2.2
  + Improvements
  * Documentation includes a section on how to use Jupytext as a Python library
  * Mention of the server extension in the documentation
  * Text notebooks can be tested with `jupytext --execute notebook.md`
  * The default value of `as_version` in `jupytext.read` is `nbformat.NO_CONVERT`, as for `nbformat.read`
  * Jupytext tests are now included in sdist
  + BugFixes
  * Fixed the download notebook error when `c.notebook_extensions` has a custom value
  * Fixed the usability of the `fmt` argument in `jupytext.read`
  * String delimiters in commented text are now ignored
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.2.1
  + Improvements
  * Added documentation on how to use Jupytext with JupyterLab 0.35
  * and on using Jupytext with the pre-commit package manager
  * The `read` and `write` functions are easier to use
  + BugFixes
  * Jupytext now ships the ``jupyterlab-jupytext`` extension in version 1.0.2. The version 1.0.1 erroneously introduces a `target_formats` metadata in the jupytext section, instead of `formats`, and works only after two clicks.
- Update to 1.2.0
  + Improvements
  * New ``--execute`` option in Jupytext CLI
  * The ``--set-formats`` option in Jupytext CLI also triggers ``--sync``, allowing shorter commands.
  * ``jupytext``'s ``read`` and ``write`` functions can be used as drop-in replacements for ``nbformat``'s ones.
  * ``jupytext --sync`` will now skip unpaired notebooks.
  * The JupyterLab extension was updated. It now works on on text filesand has a new option to include
    (or not) the metadata in the text representation of the notebook.
  * Jupytext's contents manager class is derived dynamically from the default CM class for compatibility with
    ``jupyter_server``
  * Removed dependency on ``mock`` and ``testfixtures``, thanks to Jean-Sebastien Dieu
  * Added support for `.markdown` extension
  + BugFixes
  * The ``jupyterlab-jupytext`` extension shipped with the python package is in version 1.0.1, and is compatible only
    with JupyterLab >= 1.0. If you use an earlier version of JupyterLab, please install the version 0.19 of the extension
    with ``jupyter labextension install jupyterlab-jupytext@0.19``
  * Text files can be unpaired
- Update to 1.1.7
  + Improvements
  * Added support for Scala notebook, by Tobias Frischholz
  * Added a getting started notebook for jupytext (and Binder), by Chris Holdgraf
  * The Markdown and R Markdown representations are now tested for all the languages
  * The Jupytext notebook extension also works when the notebook is a text file
  + BugFixes
  * The Jupytext Menu in Jupyter Notebook is now compatible with ``jupyter_nbextensions_configurator``
  * Entries in the Jupytext menu are updated when the menu is hovered on
  * Fixed link to ``.md`` files in the documentation
- Update to 1.1.6
  + Improvements
  * Jupytext now supports Javascript and Typescript, thanks to Hatem Hosny
  * Jupytext works with Python 3.8 as well
  + BugFixes
  * Fix global ``auto`` pairing
- Update to 1.1.5
  + BugFixes
  * Fixed implicit dependency on ``jupyter_client``
- Update to 1.1.4
  + Improvements
  * New argument ``--set-kernel`` in Jupytext command line
  * Jupytext now accepts ``--to script`` or ``--to auto``
  * Jupytext now has a real Sphinx documentation on `readthedocs
    <https://jupytext.readthedocs.io/en/latest/>`_, thanks to Chris Holdgraf
  + BugFixes
  * Invalid notebooks may cause a warning, but not a fatal error
  * Jupyter server extension leaves the contents manager unchanged if it is a sub-class of Jupytext's CM
  * Fixed format inference when metadata is present but not format information
  * Preserve executable and encoding information in scripts with metadata
* Fri May 24 2019 Todd R <toddrme2178@gmail.com>
- Make it explicit which version number to use.
* Tue Apr 30 2019 Todd R <toddrme2178@gmail.com>
- Initial version
